[prev in list] [next in list] [prev in thread] [next in thread] 

List:       squirrelmail-cvs
Subject:    [SM-CVS] SF.net SVN: squirrelmail:[14437] trunk/squirrelmail
From:       pdontthink () users ! sourceforge ! net
Date:       2014-01-21 22:15:04
Message-ID: E1W5jbA-0005oc-Rh () sfs-ml-3 ! v29 ! ch3 ! sourceforge ! com
[Download RAW message or body]

Revision: 14437
          http://sourceforge.net/p/squirrelmail/code/14437
Author:   pdontthink
Date:     2014-01-21 22:15:03 +0000 (Tue, 21 Jan 2014)
Log Message:
-----------
Variable name correction

Modified Paths:
--------------
    trunk/squirrelmail/class/deliver/Deliver.class.php
    trunk/squirrelmail/class/deliver/Deliver_SMTP.class.php
    trunk/squirrelmail/class/deliver/Deliver_SendMail.class.php
    trunk/squirrelmail/config/config_local.example.php
    trunk/squirrelmail/doc/ChangeLog
    trunk/squirrelmail/functions/imap_general.php
    trunk/squirrelmail/include/options/folder.php
    trunk/squirrelmail/plugins/filters/filters.php
    trunk/squirrelmail/plugins/filters/options.php
    trunk/squirrelmail/plugins/filters/spamoptions.php
    trunk/squirrelmail/plugins/info/options.php
    trunk/squirrelmail/plugins/mail_fetch/fetch.php
    trunk/squirrelmail/plugins/mail_fetch/functions.php
    trunk/squirrelmail/plugins/mail_fetch/options.php
    trunk/squirrelmail/plugins/message_details/message_details_bottom.php
    trunk/squirrelmail/plugins/sent_subfolders/functions.php
    trunk/squirrelmail/plugins/spamcop/functions.php
    trunk/squirrelmail/plugins/spamcop/spamcop.php
    trunk/squirrelmail/src/compose.php
    trunk/squirrelmail/src/download.php
    trunk/squirrelmail/src/empty_trash.php
    trunk/squirrelmail/src/folders.php
    trunk/squirrelmail/src/left_main.php
    trunk/squirrelmail/src/redirect.php
    trunk/squirrelmail/src/right_main.php
    trunk/squirrelmail/src/search.php
    trunk/squirrelmail/src/vcard.php
    trunk/squirrelmail/src/view_header.php
    trunk/squirrelmail/src/view_html.php
    trunk/squirrelmail/src/view_text.php

Modified: trunk/squirrelmail/class/deliver/Deliver.class.php
===================================================================
--- trunk/squirrelmail/class/deliver/Deliver.class.php	2014-01-21 21:30:59 UTC (rev \
                14436)
+++ trunk/squirrelmail/class/deliver/Deliver.class.php	2014-01-21 22:15:03 UTC (rev \
14437) @@ -90,7 +90,7 @@
         //
         if ($reply_id) {
             global $imapConnection, $username, $imapServerAddress, 
-                   $imapPort, $imapSslOptions, $mailbox;
+                   $imapPort, $imap_stream_options, $mailbox;
 
             // try our best to use an existing IMAP handle
             //
@@ -104,7 +104,7 @@
             } else {
                 $close_imap_stream = TRUE;
                 $my_imap_stream = sqimap_login($username, FALSE, $imapServerAddress,
-                                               $imapPort, 0, $imapSslOptions);
+                                               $imapPort, 0, $imap_stream_options);
             }
 
             sqimap_mailbox_select($my_imap_stream, $mailbox);
@@ -453,11 +453,11 @@
      * @param string  $pass     password to log into the SMTP server with
      * @param boolean $authpop  whether or not to use POP-before-SMTP authorization
      * @param string  $pop_host host name or IP to connect to for POP-before-SMTP \
                authorization
-     * @param array   $ssl_options SSL context options, see config_local.php for \
more details (OPTIONAL) +     * @param array   $stream_options SSL context options, \
                see config_local.example.php for more details (OPTIONAL)
      *
      * @return handle $stream file handle resource to SMTP stream
      */
-    function initStream($message, $domain, $length=0, $host='', $port='', $user='', \
$pass='', $authpop=false, $pop_host='', $ssl_options=array()) { +    function \
initStream($message, $domain, $length=0, $host='', $port='', $user='', $pass='', \
$authpop=false, $pop_host='', $stream_options=array()) {  return $stream;
     }
 

Modified: trunk/squirrelmail/class/deliver/Deliver_SMTP.class.php
===================================================================
--- trunk/squirrelmail/class/deliver/Deliver_SMTP.class.php	2014-01-21 21:30:59 UTC \
                (rev 14436)
+++ trunk/squirrelmail/class/deliver/Deliver_SMTP.class.php	2014-01-21 22:15:03 UTC \
(rev 14437) @@ -62,7 +62,7 @@
         }
     }
 
-    function initStream($message, $domain, $length=0, $host='', $port='', $user='', \
$pass='', $authpop=false, $pop_host='', $ssl_options=array()) { +    function \
initStream($message, $domain, $length=0, $host='', $port='', $user='', $pass='', \
$authpop=false, $pop_host='', $stream_options=array()) {  global \
$use_smtp_tls,$smtp_auth_mech;  
         if ($authpop) {
@@ -98,7 +98,7 @@
             if ((check_php_version(4,3)) && (extension_loaded('openssl'))) {
                 if (function_exists('stream_socket_client')) {
                     $server_address = 'ssl://' . $host . ':' . $port;
-                    $ssl_context = @stream_context_create($ssl_options);
+                    $ssl_context = @stream_context_create($stream_options);
                     $connect_timeout = ini_get('default_socket_timeout');
                     // null timeout is broken
                     if ($connect_timeout == 0)

Modified: trunk/squirrelmail/class/deliver/Deliver_SendMail.class.php
===================================================================
--- trunk/squirrelmail/class/deliver/Deliver_SendMail.class.php	2014-01-21 21:30:59 \
                UTC (rev 14436)
+++ trunk/squirrelmail/class/deliver/Deliver_SendMail.class.php	2014-01-21 22:15:03 \
UTC (rev 14437) @@ -86,7 +86,7 @@
     *
     * @param Message $message Message object containing the from address
     * @param string $sendmail_path Location of sendmail binary
-    * @param mixed $ignore Seven extra arguments that the parent class
+    * @param mixed $ignore Eight extra arguments that the parent class
     *                      requires which are not used here
     * @return resource
     * @access public

Modified: trunk/squirrelmail/config/config_local.example.php
===================================================================
--- trunk/squirrelmail/config/config_local.example.php	2014-01-21 21:30:59 UTC (rev \
                14436)
+++ trunk/squirrelmail/config/config_local.example.php	2014-01-21 22:15:03 UTC (rev \
14437) @@ -52,14 +52,14 @@
  * (those that are displayed in a different color than other
  * "normal" mailboxes).
  *
- * $smtpSslOptions allows more control over the SSL context used
- * when connecting to the SMTP server over SSL/TLS.  See:
+ * $smtp_stream_options allows more control over the SSL context
+ * used when connecting to the SMTP server over SSL/TLS.  See:
  * http://www.php.net/manual/context.php and in particular
  * http://php.net/manual/context.ssl.php
  * For example, you can specify a CA file that corresponds
  * to your server's certificate and make sure that the
  * server's certificate is validated when connecting:
- * $smtpSslOptions = array(
+ * $smtp_stream_options = array(
  *     'ssl' => array(
  *         'cafile' => '/etc/pki/tls/certs/ca-bundle.crt',
  *         'verify_peer' => true,
@@ -67,14 +67,14 @@
  *     ),
  * );
  *
- * $imapSslOptions allows more control over the SSL context used
- * when connecting to the IMAP server over SSL/TLS.  See:
- * http://www.php.net/manual/context.php and in particular
- * http://php.net/manual/context.ssl.php
+ * $imap_stream_options allows more control over the SSL
+ * context used when connecting to the IMAP server over
+ * SSL/TLS.  See: http://www.php.net/manual/context.php
+ * and in particular http://php.net/manual/context.ssl.php
  * For example, you can specify a CA file that corresponds
  * to your server's certificate and make sure that the
  * server's certificate is validated when connecting:
- * $imapSslOptions = array(
+ * $imap_stream_options = array(
  *     'ssl' => array(
  *         'cafile' => '/etc/pki/tls/certs/ca-bundle.crt',
  *         'verify_peer' => true,

Modified: trunk/squirrelmail/doc/ChangeLog
===================================================================
--- trunk/squirrelmail/doc/ChangeLog	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/doc/ChangeLog	2014-01-21 22:15:03 UTC (rev 14437)
@@ -385,7 +385,7 @@
     shown on the message list screen
   - Added advanced control over the SSL context used when connecting
     to the SMTP and IMAP servers over SSL/TLS (thanks to Emmanuel
-    Dreyfus).  See $imapSslOptions and $smtpSslOptions in
+    Dreyfus).  See $imap_stream_options and $smtp_stream_options in
     config_local.example.php for more information.
   - Added ability to show login error from the IMAP server instead of
     traditional "Unknown user or password incorrect" (thanks to Alain

Modified: trunk/squirrelmail/functions/imap_general.php
===================================================================
--- trunk/squirrelmail/include/options/folder.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/include/options/folder.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -33,12 +33,12 @@
  * @return array all option information
  */
 function load_optpage_data_folder() {
-    global $username, $imapServerAddress, $imapPort, $imapSslOptions,
+    global $username, $imapServerAddress, $imapPort, $imap_stream_options,
            $oTemplate, $nbsp, $folder_prefix, $default_folder_prefix,
            $show_prefix_option;
 
     /* Get some imap data we need later. */
-    $imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, \
0, $imapSslOptions); +    $imapConnection = sqimap_login($username, false, \
$imapServerAddress, $imapPort, 0, $imap_stream_options);  $boxes = \
sqimap_mailbox_list($imapConnection);  
     /* Build a simple array into which we will build options. */

Modified: trunk/squirrelmail/plugins/filters/filters.php
===================================================================
--- trunk/squirrelmail/plugins/filters/filters.php	2014-01-21 21:30:59 UTC (rev \
                14436)
+++ trunk/squirrelmail/plugins/filters/filters.php	2014-01-21 22:15:03 UTC (rev \
14437) @@ -190,7 +190,7 @@
  * @access private
  */
 function start_filters($hook_args) {
-    global $imapServerAddress, $imapPort, $imapSslOptions, $imap_stream,
+    global $imapServerAddress, $imapPort, $imap_stream_options, $imap_stream,
            $imapConnection, $UseSeparateImapConnection, $AllowSpamFilters,
            $filter_inbox_count, $username;
 
@@ -229,7 +229,7 @@
     if ((!isset($imap_stream) && !isset($imapConnection)) ||
         $UseSeparateImapConnection ) {
             $stream = sqimap_login($username, false, $imapServerAddress,
-                                $imapPort, 10, $imapSslOptions);
+                                $imapPort, 10, $imap_stream_options);
             $previously_connected = false;
     } else if (isset($imapConnection)) {
         $stream = $imapConnection;

Modified: trunk/squirrelmail/plugins/filters/options.php
===================================================================
--- trunk/squirrelmail/plugins/filters/options.php	2014-01-21 21:30:59 UTC (rev \
                14436)
+++ trunk/squirrelmail/plugins/filters/options.php	2014-01-21 22:15:03 UTC (rev \
14437) @@ -25,7 +25,7 @@
 
 sqgetGlobalVar('theid', $theid);
 sqgetGlobalVar('action', $action, SQ_GET);
-global $imapSslOptions; // in case not defined in config
+global $imap_stream_options; // in case not defined in config
 
 if (sqgetGlobalVar('filter_submit',$filter_submit,SQ_POST)) {
 
@@ -126,7 +126,7 @@
 
     if (isset($action) && ($action == 'add' || $action == 'edit')) {
 
-        $imapConnection = sqimap_login($username, false, $imapServerAddress, \
$imapPort, 0, $imapSslOptions); +        $imapConnection = sqimap_login($username, \
false, $imapServerAddress, $imapPort, 0, $imap_stream_options);  $boxes = \
sqimap_mailbox_list($imapConnection);  
         for ($a = 0, $cnt = count($boxes); $a < $cnt; $a++) {

Modified: trunk/squirrelmail/plugins/filters/spamoptions.php
===================================================================
--- trunk/squirrelmail/plugins/filters/spamoptions.php	2014-01-21 21:30:59 UTC (rev \
                14436)
+++ trunk/squirrelmail/plugins/filters/spamoptions.php	2014-01-21 22:15:03 UTC (rev \
14437) @@ -23,7 +23,7 @@
 sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
 
 sqgetGlobalVar('action', $action, SQ_GET);
-global $imapSslOptions; // in case not defined in config
+global $imap_stream_options; // in case not defined in config
 /* end globals */
 
 displayPageHeader($color);
@@ -78,7 +78,7 @@
 
 
 if (isset($action) && $action == 'spam') {
-    $imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, \
0, $imapSslOptions); +    $imapConnection = sqimap_login($username, false, \
$imapServerAddress, $imapPort, 0, $imap_stream_options);  $boxes = \
sqimap_mailbox_list($imapConnection);  sqimap_logout($imapConnection);
     $numboxes = count($boxes);

Modified: trunk/squirrelmail/plugins/info/options.php
===================================================================
--- trunk/squirrelmail/plugins/info/options.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/plugins/info/options.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -53,8 +53,8 @@
 
 /* END GLOBALS */
 
-global $imapSslOptions; // in case not defined in config
-$imap_stream = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imapSslOptions); +global $imap_stream_options; // in case not defined in config
+$imap_stream = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imap_stream_options);  $caps_array = get_caps($imap_stream);
 $list = array ('TEST_0',
                'TEST_1',

Modified: trunk/squirrelmail/plugins/mail_fetch/fetch.php
===================================================================
--- trunk/squirrelmail/plugins/mail_fetch/fetch.php	2014-01-21 21:30:59 UTC (rev \
                14436)
+++ trunk/squirrelmail/plugins/mail_fetch/fetch.php	2014-01-21 22:15:03 UTC (rev \
14437) @@ -27,7 +27,7 @@
 
 /* globals */
 sqgetGlobalVar('delimiter',  $delimiter,  SQ_SESSION);
-global $imapSslOptions; // in case not defined in config
+global $imap_stream_options; // in case not defined in config
 /* end globals */
 
 /**
@@ -198,7 +198,7 @@
     }
 
     Mail_Fetch_Status(_("Opening IMAP server"));
-    $imap_stream = sqimap_login($username, false, $imapServerAddress, $imapPort, 10, \
$imapSslOptions); +    $imap_stream = sqimap_login($username, false, \
$imapServerAddress, $imapPort, 10, $imap_stream_options);  
     // check if destination folder is not set, is not subscribed and is not \
\noselect folder  if($mailfetch_subfolder == '' ||

Modified: trunk/squirrelmail/plugins/mail_fetch/functions.php
===================================================================
--- trunk/squirrelmail/plugins/mail_fetch/functions.php	2014-01-21 21:30:59 UTC (rev \
                14436)
+++ trunk/squirrelmail/plugins/mail_fetch/functions.php	2014-01-21 22:15:03 UTC (rev \
14437) @@ -64,7 +64,7 @@
 function mail_fetch_login_function() {
     include_once (SM_PATH . 'functions/imap_general.php');
 
-    global $username, $data_dir, $imapServerAddress, $imapPort, $imapSslOptions;
+    global $username, $data_dir, $imapServerAddress, $imapPort, \
$imap_stream_options;  
     $mailfetch_newlog = getPref($data_dir, $username, 'mailfetch_newlog');
 
@@ -129,7 +129,7 @@
                 continue;
             }
 
-            $imap_stream = sqimap_login($username, false, $imapServerAddress, \
$imapPort, 10, $imapSslOptions); +            $imap_stream = sqimap_login($username, \
false, $imapServerAddress, $imapPort, 10, $imap_stream_options);  
             /* log into pop server*/
             if (! $pop3->login($mailfetch_user, $mailfetch_pass)) {

Modified: trunk/squirrelmail/plugins/mail_fetch/options.php
===================================================================
--- trunk/squirrelmail/plugins/mail_fetch/options.php	2014-01-21 21:30:59 UTC (rev \
                14436)
+++ trunk/squirrelmail/plugins/mail_fetch/options.php	2014-01-21 22:15:03 UTC (rev \
14437) @@ -59,7 +59,7 @@
 $mf_port = trim($mf_port);
 $mf_server = trim($mf_server);
 
-global $imapSslOptions; // in case not defined in config
+global $imap_stream_options; // in case not defined in config
 
 /* end globals */
 
@@ -302,7 +302,7 @@
          html_tag( 'tr' ) .
              html_tag( 'th', _("Store in Folder:"), 'right' ) .
              html_tag( 'td', '', 'left' );
-     $imapConnection = sqimap_login ($username, false, $imapServerAddress, \
$imapPort, 0, $imapSslOptions); +     $imapConnection = sqimap_login ($username, \
false, $imapServerAddress, $imapPort, 0, $imap_stream_options);  $boxes = \
sqimap_mailbox_list($imapConnection);  echo '<select name="mf_subfolder">';
 
@@ -437,7 +437,7 @@
                  html_tag( 'th', _("Store in Folder:"), 'right' ) .
                  html_tag( 'td', '', 'left' );
 
-     $imapConnection = sqimap_login ($username, false, $imapServerAddress, \
$imapPort, 0, $imapSslOptions); +     $imapConnection = sqimap_login ($username, \
false, $imapServerAddress, $imapPort, 0, $imap_stream_options);  $boxes = \
sqimap_mailbox_list($imapConnection);  echo '<select name="mf_subfolder">';
      $selected = 0;

Modified: trunk/squirrelmail/plugins/message_details/message_details_bottom.php
===================================================================
--- trunk/squirrelmail/plugins/message_details/message_details_bottom.php	2014-01-21 \
                21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/plugins/message_details/message_details_bottom.php	2014-01-21 \
22:15:03 UTC (rev 14437) @@ -112,12 +112,12 @@
  * @access public
  */
 function get_message_details($mailbox, $passed_id, $passed_ent_id=0, \
                $stripHTML=FALSE) {
-    global $imapServerAddress, $imapPort, $imapSslOptions,
+    global $imapServerAddress, $imapPort, $imap_stream_options,
            $color,$msgd_8bit_in_hex, $username;
 
     $returnValue = '';
 
-    $imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, \
0, $imapSslOptions); +    $imapConnection = sqimap_login($username, false, \
$imapServerAddress, $imapPort, 0, $imap_stream_options);  $read = \
sqimap_mailbox_select($imapConnection, $mailbox);  if (!empty($passed_ent_id))
         $body = sqimap_run_command($imapConnection, "FETCH $passed_id \
BODY[$passed_ent_id]",true, $response, $readmessage, TRUE);

Modified: trunk/squirrelmail/plugins/sent_subfolders/functions.php
===================================================================
--- trunk/squirrelmail/plugins/sent_subfolders/functions.php	2014-01-21 21:30:59 UTC \
                (rev 14436)
+++ trunk/squirrelmail/plugins/sent_subfolders/functions.php	2014-01-21 22:15:03 UTC \
(rev 14437) @@ -50,10 +50,10 @@
 function sent_subfolders_optpage_loadhook_folders_do() {
 
     global $data_dir, $username, $optpage_data, $imapServerAddress,
-           $imapPort, $imapSslOptions, $show_contain_subfolders_option, \
$sent_folder; +           $imapPort, $imap_stream_options, \
$show_contain_subfolders_option, $sent_folder;  
     /* Get some imap data we need later. */
-    $imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, \
0, $imapSslOptions); +    $imapConnection = sqimap_login($username, false, \
$imapServerAddress, $imapPort, 0, $imap_stream_options);  $boxes = \
sqimap_mailbox_list($imapConnection);  sqimap_logout($imapConnection);
 
@@ -161,7 +161,7 @@
 function sent_subfolders_update_sentfolder_do() {
     global $sent_folder, $username,
            $data_dir, $imapServerAddress, $imapPort,
-           $imapSslOptions, $move_to_sent;
+           $imap_stream_options, $move_to_sent;
 
     sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
 
@@ -218,7 +218,7 @@
             /* Auto-create folders, if they do not yet exist. */
             if ($sent_subfolder != 'none') {
                 /* Create the imap connection. */
-                $ic = sqimap_login($username, false, $imapServerAddress, $imapPort, \
10, $imapSslOptions); +                $ic = sqimap_login($username, false, \
$imapServerAddress, $imapPort, 10, $imap_stream_options);  
                 $boxes = false;
                 /**

Modified: trunk/squirrelmail/plugins/spamcop/functions.php
===================================================================
--- trunk/squirrelmail/plugins/spamcop/functions.php	2014-01-21 21:30:59 UTC (rev \
                14436)
+++ trunk/squirrelmail/plugins/spamcop/functions.php	2014-01-21 22:15:03 UTC (rev \
14437) @@ -134,12 +134,12 @@
  */
 function spamcop_while_sending_function() {
     global $mailbox, $spamcop_delete, $spamcop_save, $spamcop_is_composing, \
                $auto_expunge,
-           $username, $imapServerAddress, $imapPort, $imapSslOptions;
+           $username, $imapServerAddress, $imapPort, $imap_stream_options;
 
     if (sqgetGlobalVar('spamcop_is_composing' , $spamcop_is_composing)) {
         // delete spam message
         if ($spamcop_delete) {
-            $imapConnection = sqimap_login($username, false, $imapServerAddress, \
$imapPort, 0, $imapSslOptions); +            $imapConnection = \
sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imap_stream_options);  sqimap_mailbox_select($imapConnection, $mailbox);
             sqimap_msgs_list_delete($imapConnection, $mailbox, \
array($spamcop_is_composing));  if ($auto_expunge)

Modified: trunk/squirrelmail/plugins/spamcop/spamcop.php
===================================================================
--- trunk/squirrelmail/plugins/spamcop/spamcop.php	2014-01-21 21:30:59 UTC (rev \
                14436)
+++ trunk/squirrelmail/plugins/spamcop/spamcop.php	2014-01-21 22:15:03 UTC (rev \
14437) @@ -66,8 +66,8 @@
     exit();
 }
 
-    global $imapSslOptions; // in case not defined in config
-    $imap_stream = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imapSslOptions); +    global $imap_stream_options; // in case not defined in config
+    $imap_stream = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imap_stream_options);  sqimap_mailbox_select($imap_stream, $mailbox);
 
     if ($spamcop_method == 'quick_email' ||

Modified: trunk/squirrelmail/src/compose.php
===================================================================
--- trunk/squirrelmail/src/compose.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/compose.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -41,7 +41,7 @@
 require_once(SM_PATH . 'functions/addressbook.php');
 require_once(SM_PATH . 'functions/forms.php');
 require_once(SM_PATH . 'functions/identity.php');
-global $imapSslOptions; // in case not defined in config
+global $imap_stream_options; // in case not defined in config
 
 /* --------------------- Get globals ------------------------------------- */
 
@@ -430,7 +430,7 @@
         $draft_message = _("Draft Email Saved");
         /* If this is a resumed draft, then delete the original */
         if(isset($delete_draft)) {
-            $imap_stream = sqimap_login($username, false, $imapServerAddress, \
$imapPort, false, $imapSslOptions); +            $imap_stream = \
sqimap_login($username, false, $imapServerAddress, $imapPort, false, \
$imap_stream_options);  sqimap_mailbox_select($imap_stream, $draft_folder);
             // force bypass_trash=true because message should be saved when \
                deliverMessage() returns true.
             // in current implementation of sqimap_msgs_list_flag() single message \
id can @@ -543,7 +543,7 @@
 
         /* if it is resumed draft, delete draft message */
         if ( isset($delete_draft)) {
-            $imap_stream = sqimap_login($username, false, $imapServerAddress, \
$imapPort, false, $imapSslOptions); +            $imap_stream = \
sqimap_login($username, false, $imapServerAddress, $imapPort, false, \
$imap_stream_options);  sqimap_mailbox_select($imap_stream, $draft_folder);
             // bypass_trash=true because message should be saved when \
                deliverMessage() returns true.
             // in current implementation of sqimap_msgs_list_flag() single message \
id can @@ -774,7 +774,7 @@
 function newMail ($mailbox='', $passed_id='', $passed_ent_id='', $action='', \
$session='') {  global $editor_size, $default_use_priority, $body, $idents,
         $use_signature, $data_dir, $username,
-        $key, $imapServerAddress, $imapPort, $imapSslOptions,
+        $key, $imapServerAddress, $imapPort, $imap_stream_options,
         $composeMessage, $body_quote, $request_mdn, $request_dr,
         $mdn_user_support, $languages, $squirrelmail_language,
         $default_charset, $do_not_reply_to_self;
@@ -791,7 +791,7 @@
 
     if ($passed_id) {
         $imapConnection = sqimap_login($username, false, $imapServerAddress,
-                $imapPort, 0, $imapSslOptions);
+                $imapPort, 0, $imap_stream_options);
 
         sqimap_mailbox_select($imapConnection, $mailbox);
         $message = sqimap_get_message($imapConnection, $passed_id, $mailbox);
@@ -1681,7 +1681,7 @@
         $username, $identity, $idents, $data_dir,
         $request_mdn, $request_dr, $default_charset, $useSendmail,
         $domain, $action, $default_move_to_sent, $move_to_sent,
-        $imapServerAddress, $imapPort, $imapSslOptions, $sent_folder, $key;
+        $imapServerAddress, $imapPort, $imap_stream_options, $sent_folder, $key;
 
     $rfc822_header = $composeMessage->rfc822_header;
 
@@ -1778,13 +1778,13 @@
     if (!$useSendmail && !$draft) {
         require_once(SM_PATH . 'class/deliver/Deliver_SMTP.class.php');
         $deliver = new Deliver_SMTP();
-        global $smtpServerAddress, $smtpPort, $smtpSslOptions, $pop_before_smtp, \
$pop_before_smtp_host; +        global $smtpServerAddress, $smtpPort, \
$smtp_stream_options, $pop_before_smtp, $pop_before_smtp_host;  
         $authPop = (isset($pop_before_smtp) && $pop_before_smtp) ? true : false;
         if (empty($pop_before_smtp_host)) $pop_before_smtp_host = \
$smtpServerAddress;  get_smtp_user($user, $pass);
         $stream = $deliver->initStream($composeMessage,$domain,0,
-                $smtpServerAddress, $smtpPort, $user, $pass, $authPop, \
$pop_before_smtp_host, $smtpSslOptions); +                $smtpServerAddress, \
$smtpPort, $user, $pass, $authPop, $pop_before_smtp_host, $smtp_stream_options);  } \
                elseif (!$draft) {
         require_once(SM_PATH . 'class/deliver/Deliver_SendMail.class.php');
         global $sendmail_path, $sendmail_args;
@@ -1801,7 +1801,7 @@
     } elseif ($draft) {
         global $draft_folder;
         $imap_stream = sqimap_login($username, false, $imapServerAddress,
-                $imapPort, 0, $imapSslOptions);
+                $imapPort, 0, $imap_stream_options);
         if (sqimap_mailbox_exists ($imap_stream, $draft_folder)) {
             require_once(SM_PATH . 'class/deliver/Deliver_IMAP.class.php');
             $imap_deliver = new Deliver_IMAP();
@@ -1837,7 +1837,7 @@
         plain_error_message($msg);
     } else {
         unset ($deliver);
-        $imap_stream = sqimap_login($username, false, $imapServerAddress, $imapPort, \
0, $imapSslOptions); +        $imap_stream = sqimap_login($username, false, \
$imapServerAddress, $imapPort, 0, $imap_stream_options);  
 
         // mark as replied or forwarded if applicable

Modified: trunk/squirrelmail/src/download.php
===================================================================
--- trunk/squirrelmail/src/download.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/download.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -58,8 +58,8 @@
 
 /* end globals */
 
-global $imapSslOptions; // in case not defined in config
-$imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imapSslOptions); +global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imap_stream_options);  $aMailbox = sqm_api_mailbox_select($imapConnection, $account, \
$mailbox,array(),array());  
 if (isset($aMailbox['MSG_HEADERS'][$passed_id]['MESSAGE_OBJECT']) &&

Modified: trunk/squirrelmail/src/empty_trash.php
===================================================================
--- trunk/squirrelmail/src/empty_trash.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/empty_trash.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -34,8 +34,8 @@
 sqgetGlobalVar('smtoken', $submitted_token, SQ_GET, '');
 sm_validate_security_token($submitted_token, -1, TRUE);
 
-global $imapSslOptions; // in case not defined in config
-$imap_stream = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imapSslOptions); +global $imap_stream_options; // in case not defined in config
+$imap_stream = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imap_stream_options);  
 $mailbox = $trash_folder;
 $boxes = sqimap_mailbox_list($imap_stream);

Modified: trunk/squirrelmail/src/folders.php
===================================================================
--- trunk/squirrelmail/src/folders.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/folders.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -34,8 +34,8 @@
 
 /* end of get globals */
 
-global $imapSslOptions; // in case not defined in config
-$imapConnection = sqimap_login ($username, false, $imapServerAddress, $imapPort, 0, \
$imapSslOptions); +global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login ($username, false, $imapServerAddress, $imapPort, 0, \
$imap_stream_options);  
 /* switch to the right function based on what the user selected */
 if ( sqgetGlobalVar('smaction', $action, SQ_POST) ) {

Modified: trunk/squirrelmail/src/left_main.php
===================================================================
--- trunk/squirrelmail/src/left_main.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/left_main.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -38,8 +38,8 @@
 
 // open a connection on the imap port (143)
 // why hide the output?
-global $imapSslOptions; // in case not defined in config
-$imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, \
true, $imapSslOptions); +global $imap_stream_options; // in case not defined in \
config +$imapConnection = sqimap_login($username, false, $imapServerAddress, \
$imapPort, true, $imap_stream_options);  
 /**
  * Using stristr since very old preferences may contain "None" and "none".

Modified: trunk/squirrelmail/src/redirect.php
===================================================================
--- trunk/squirrelmail/src/redirect.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/redirect.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -71,8 +71,8 @@
 }
 
 /* Verify that username and password are correct. */
-global $imapSslOptions; // in case not defined in config
-$imapConnection = sqimap_login($login_username, $key, $imapServerAddress, $imapPort, \
0, $imapSslOptions); +global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($login_username, $key, $imapServerAddress, $imapPort, \
0, $imap_stream_options);  /* From now on we are logged it. If the login failed then \
sqimap_login handles it */  
 /**

Modified: trunk/squirrelmail/src/right_main.php
===================================================================
--- trunk/squirrelmail/src/right_main.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/right_main.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -88,8 +88,8 @@
 
 /* Open an imap connection */
 
-global $imapSslOptions; // in case not defined in config
-$imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imapSslOptions); +global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imap_stream_options);  
 $mailbox = (isset($mailbox) && $mailbox) ? $mailbox : 'INBOX';
 

Modified: trunk/squirrelmail/src/search.php
===================================================================
--- trunk/squirrelmail/src/search.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/search.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -1321,8 +1321,8 @@
 uasort($imap_asearch_options, 'asearch_unhtml_strcoll');
 
 /* open IMAP connection */
-global $imapSslOptions; // in case not defined in config
-$imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imapSslOptions); +global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imap_stream_options);  
 
 /* get mailboxes once here */

Modified: trunk/squirrelmail/src/vcard.php
===================================================================
--- trunk/squirrelmail/src/vcard.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/vcard.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -41,8 +41,8 @@
 sqgetGlobalVar('startMessage', $startMessage, SQ_GET);
 /* end globals */
 
-global $imapSslOptions; // in case not defined in config
-$imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imapSslOptions); +global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imap_stream_options);  sqimap_mailbox_select($imapConnection, $mailbox);
 
 displayPageHeader($color);

Modified: trunk/squirrelmail/src/view_header.php
===================================================================
--- trunk/squirrelmail/src/view_header.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/view_header.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -93,9 +93,9 @@
 }
 sqgetGlobalVar('delimiter',  $delimiter,    SQ_SESSION);
 
-global $imapSslOptions; // in case not defined in config
+global $imap_stream_options; // in case not defined in config
 $imapConnection = sqimap_login($username, false, $imapServerAddress,
-                               $imapPort, 0, $imapSslOptions);
+                               $imapPort, 0, $imap_stream_options);
 $mbx_response = sqimap_mailbox_select($imapConnection, $mailbox, false, false, \
true);  $header = parse_viewheader($imapConnection,$passed_id, $passed_ent_id);
 

Modified: trunk/squirrelmail/src/view_html.php
===================================================================
--- trunk/squirrelmail/src/view_html.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/view_html.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -38,8 +38,8 @@
 
 // TODO: add required var checks here.
 
-global $imapSslOptions; // in case not defined in config
-$imap_stream = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imapSslOptions); +global $imap_stream_options; // in case not defined in config
+$imap_stream = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imap_stream_options);  $mbx_response = sqimap_mailbox_select($imap_stream, \
$mailbox);  
 $message = &$messages[$mbx_response['UIDVALIDITY']][$passed_id];

Modified: trunk/squirrelmail/src/view_text.php
===================================================================
--- trunk/squirrelmail/src/view_text.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/src/view_text.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -29,8 +29,8 @@
 sqgetGlobalVar('QUERY_STRING', $QUERY_STRING, SQ_SERVER);
 sqgetGlobalVar('passed_id', $passed_id, SQ_GET, NULL, SQ_TYPE_BIGINT);
 
-global $imapSslOptions; // in case not defined in config
-$imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imapSslOptions); +global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, false, $imapServerAddress, $imapPort, 0, \
$imap_stream_options);  $mbx_response = sqimap_mailbox_select($imapConnection, \
$mailbox);  
 $message = &$messages[$mbx_response['UIDVALIDITY']][$passed_id];

This was sent by the SourceForge.net collaborative development platform, the world's \
largest Open Source development site.


------------------------------------------------------------------------------
CenturyLink Cloud: The Leader in Enterprise Cloud Services.
Learn Why More Businesses Are Choosing CenturyLink Cloud For
Critical Workloads, Development Environments & Everything In Between.
Get a Quote or Start a Free Trial Today. 
http://pubads.g.doubleclick.net/gampad/clk?id=119420431&iu=/4140/ostg.clktrk
-----
squirrelmail-cvs mailing list
List address: squirrelmail-cvs@lists.sourceforge.net
List info (subscribe/unsubscribe/change options): \
                https://lists.sourceforge.net/lists/listinfo/squirrelmail-cvs
Repository: http://squirrelmail.org/svn


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic
--- trunk/squirrelmail/functions/imap_general.php	2014-01-21 21:30:59 UTC (rev 14436)
+++ trunk/squirrelmail/functions/imap_general.php	2014-01-21 22:15:03 UTC (rev 14437)
@@ -670,12 +670,12 @@
  * @param int port port number to connect to
  * @param integer $tls whether to use plain text(0), TLS(1) or STARTTLS(2) when \
                connecting.
  *  Argument was boolean before 1.5.1.
  * @param array $ssl_options SSL context options, see config_local.php
  *                           for more details (OPTIONAL)
  * @return imap-stream resource identifier
  * @since 1.5.0 (usable only in 1.5.1 or later)
  */
-function sqimap_create_stream($server,$port,$tls=0,$ssl_options=array()) {
+function sqimap_create_stream($server,$port,$tls=0,$stream_options=array()) {
     global $squirrelmail_language;
 
     if (strstr($server,':') && ! preg_match("/^\[.*\]$/",$server)) {
@@ -691,7 +691,7 @@
         if ((check_php_version(4,3)) and (extension_loaded('openssl'))) {
             if (function_exists('stream_socket_client')) {
                 $server_address = 'ssl://' . $server . ':' . $port;
-                $ssl_context = @stream_context_create($ssl_options);
+                $ssl_context = @stream_context_create($stream_options);
                 $connect_timeout = ini_get('default_socket_timeout');
                 // null timeout is broken
                 if ($connect_timeout == 0)
@@ -810,14 +810,14 @@
  *                  1 = show no errors (just exit)
  *                  2 = show no errors (return FALSE)
  *                  3 = show no errors (return error string)
  * @param array $ssl_options SSL context options, see config_local.php
  *                           for more details (OPTIONAL)
  * @return mixed The IMAP connection stream, or if the connection fails,
  *               FALSE if $hide is set to 2 or an error string if $hide
  *               is set to 3.
  */
 function sqimap_login ($username, $password, $imap_server_address,
-                       $imap_port, $hide, $ssl_options=array()) {
+                       $imap_port, $hide, $stream_options=array()) {
     global $color, $squirrelmail_language, $onetimepad, $use_imap_tls,
            $imap_auth_mech, $sqimap_capabilities, $display_imap_login_error;
 
@@ -865,7 +865,7 @@
     $host = $imap_server_address;
     $imap_server_address = sqimap_get_user_server($imap_server_address, $username);
 
-    $imap_stream = sqimap_create_stream($imap_server_address,$imap_port,$use_imap_tls,$ssl_options);
 +    $imap_stream = \
sqimap_create_stream($imap_server_address,$imap_port,$use_imap_tls,$stream_options);  \
                
@@ -670,12 +670,12 @@
                connecting.
  *  Argument was boolean before 1.5.1.
- * @param array $ssl_options SSL context options, see config_local.php
+ * @param array $stream_options Stream context options, see config_local.php
  *                           for more details (OPTIONAL)
  * @return imap-stream resource identifier
@@ -810,14 +810,14 @@
  *                  2 = show no errors (return FALSE)
  *                  3 = show no errors (return error string)
- * @param array $ssl_options SSL context options, see config_local.php
+ * @param array $stream_options Stream context options, see config_local.php
  *                           for more details (OPTIONAL)
  * @return mixed The IMAP connection stream, or if the connection fails,
     if (($imap_auth_mech == 'cram-md5') OR ($imap_auth_mech == 'digest-md5')) {
         // We're using some sort of authentication OTHER than plain or login

Modified: trunk/squirrelmail/include/options/folder.php
===================================================================